package com.ruoyi.quotation.service;

import com.ruoyi.quotation.domain.TSeapriceQueryLog;

import java.util.List;

/**
 * 海运价格查询日志记录Service接口
 * 
 * @author frank
 * @date 2021-07-16
 */
public interface ITSeapriceQueryLogService 
{
    /**
     * 查询海运价格查询日志记录
     * 
     * @param fId 海运价格查询日志记录ID
     * @return 海运价格查询日志记录
     */
    public TSeapriceQueryLog selectTSeapriceQueryLogById(Long fId);

    /**
     * 查询海运价格查询日志记录列表
     * 
     * @param tSeapriceQueryLog 海运价格查询日志记录
     * @return 海运价格查询日志记录集合
     */
    public List<TSeapriceQueryLog> selectTSeapriceQueryLogList(TSeapriceQueryLog tSeapriceQueryLog);

    /**
     * 新增海运价格查询日志记录
     * 
     * @param tSeapriceQueryLog 海运价格查询日志记录
     * @return 结果
     */
    public int insertTSeapriceQueryLog(TSeapriceQueryLog tSeapriceQueryLog);

    /**
     * 修改海运价格查询日志记录
     * 
     * @param tSeapriceQueryLog 海运价格查询日志记录
     * @return 结果
     */
    public int updateTSeapriceQueryLog(TSeapriceQueryLog tSeapriceQueryLog);

    /**
     * 批量删除海运价格查询日志记录
     * 
     * @param fIds 需要删除的海运价格查询日志记录ID
     * @return 结果
     */
    public int deleteTSeapriceQueryLogByIds(Long[] fIds);

    /**
     * 删除海运价格查询日志记录信息
     * 
     * @param fId 海运价格查询日志记录ID
     * @return 结果
     */
    public int deleteTSeapriceQueryLogById(Long fId);
}
